@@ -7,8 +7,9 @@
 
 #include "jacobi.hpp"
 
-#include <pika/chrono.hpp>
-#include <pika/future.hpp>
+#include <pika/execution.hpp>
+#include <pika/functional/bind_front.hpp>
+#include <pika/timing/high_resolution_timer.hpp>
 
 #include <chrono>
 #include <cstddef>
@@ -18,6 +19,9 @@
 #include <utility>
 #include <vector>
 
+namespace ex = pika::execution::experimental;
+namespace tt = pika::this_thread::experimental;
+
 namespace jacobi_smp {
 
     void jacobi_kernel_wrap(range const& y_range, std::size_t n, std::vector<double>& dst,
@@ -39,13 +43,13 @@ namespace jacobi_smp {
         std::shared_ptr<vector> grid_new(new vector(n * n, 1));
         std::shared_ptr<vector> grid_old(new vector(n * n, 1));
 
-        using deps_vector = std::vector<pika::shared_future<void>>;
+        using deps_vector = std::vector<ex::any_sender<>>;
 
         std::size_t n_block = static_cast<std::size_t>(
             std::ceil(static_cast<double>(n) / static_cast<double>(block_size)));
 
-        std::shared_ptr<deps_vector> deps_new(new deps_vector(n_block, pika::make_ready_future()));
-        std::shared_ptr<deps_vector> deps_old(new deps_vector(n_block, pika::make_ready_future()));
+        std::shared_ptr<deps_vector> deps_new(new deps_vector(n_block, ex::just()));
+        std::shared_ptr<deps_vector> deps_old(new deps_vector(n_block, ex::just()));
 
         pika::chrono::detail::high_resolution_timer t;
         for (std::size_t i = 0; i < iterations; ++i)
@@ -53,40 +57,24 @@ namespace jacobi_smp {
             for (std::size_t y = 1, j = 0; y < n - 1; y += block_size, ++j)
             {
                 std::size_t y_end = (std::min)(y + block_size, n - 1);
-                std::vector<pika::shared_future<void>> trigger;
+                deps_vector trigger;
                 trigger.reserve(3);
                 trigger.push_back((*deps_old)[j]);
                 if (j > 0) trigger.push_back((*deps_old)[j - 1]);
                 if (j + 1 < n_block) trigger.push_back((*deps_old)[j + 1]);
 
-                /*
-                 * FIXME: dataflow seems to have some raceconditions
-                 * left
-                (*deps_new)[j]
-                    = pika::dataflow(
-                        pika::util::detail::bind(
-                            jacobi_kernel_wrap
-                          , range(y, y_end)
-                          , n
-                          , std::ref(*grid_new)
-                          , std::cref(*grid_old)
-                        )
-                      , trigger
-                    );
-                */
-
-                (*deps_new)[j] =
-                    pika::when_all(std::move(trigger))
-                        .then(pika::launch::async,
-                            pika::util::detail::bind(jacobi_kernel_wrap, range(y, y_end), n,
-                                std::ref(*grid_new), std::cref(*grid_old)));
+                (*deps_new)[j] = ex::when_all_vector(std::move(trigger)) |
+                    ex::transfer(ex::thread_pool_scheduler{}) |
+                    ex::then(pika::util::detail::bind_front(jacobi_kernel_wrap, range(y, y_end), n,
+                        std::ref(*grid_new), std::cref(*grid_old))) |
+                    ex::split();
             }
 
             std::swap(grid_new, grid_old);
             std::swap(deps_new, deps_old);
         }
-        pika::wait_all(*deps_new);
-        pika::wait_all(*deps_old);
+        tt::sync_wait(ex::when_all_vector(std::move(*deps_new)));
+        tt::sync_wait(ex::when_all_vector(std::move(*deps_old)));
 
         report_timing(n, iterations, t.elapsed<std::chrono::seconds>());
         output_grid(output_filename, *grid_old, n);
