@@ -161,14 +161,24 @@
 #define PIKA_CDECL
 #endif
 
-#if defined(PIKA_HAVE_SANITIZERS)
-#  if defined(__has_feature)
-#  if __has_feature(address_sanitizer)
-#      define PIKA_HAVE_ADDRESS_SANITIZER
-#    endif
-#  elif defined(__SANITIZE_ADDRESS__)   // MSVC defines this
-#    define PIKA_HAVE_ADDRESS_SANITIZER
-#  endif
-#endif
 // clang-format on
+# if defined(PIKA_HAVE_SANITIZERS)
+#  if defined(__has_feature)
+#   if __has_feature(address_sanitizer)
+#    define PIKA_HAVE_ADDRESS_SANITIZER
+#    if defined(PIKA_GCC_VERSION) || defined(PIKA_CLANG_VERSION)
+#     define PIKA_NO_SANITIZE_ADDRESS __attribute__((no_sanitize("address")))
+#    endif
+#   endif
+#   if __has_feature(thread_sanitizer)
+#    define PIKA_HAVE_THREAD_SANITIZER
+#   endif
+#  elif defined(__SANITIZE_ADDRESS__)    // MSVC defines this
+#   define PIKA_HAVE_ADDRESS_SANITIZER
+#  endif
+# endif
+#endif
+
+#if !defined(PIKA_NO_SANITIZE_ADDRESS)
+# define PIKA_NO_SANITIZE_ADDRESS
 #endif
