@@ -292,7 +292,7 @@ namespace pika::split_detail {
                     // the vector must see predecessor_done = true after
                     // taking the lock in their threads and will not add
                     // continuations to the vector.
-                    std::unique_lock<mutex_type> l{mtx};
+                    std::lock_guard<mutex_type> l{mtx};
                 }
 
                 if (!continuations.empty())
@@ -360,7 +360,7 @@ namespace pika::split_detail {
                 if (!start_called.exchange(true))
                 {
                     PIKA_ASSERT(os.has_value());
-                    pika::execution::experimental::start(os.value());
+                    pika::execution::experimental::start(*os);
                 }
             }
 
