@@ -129,9 +129,9 @@ namespace pika::split_tuple_detail {
                 r.state.set_predecessor_done();
             };
 
-                // This typedef is duplicated from the parent struct. The
-                // parent typedef is not instantiated early enough for use
-                // here.
+            // This typedef is duplicated from the parent struct. The
+            // parent typedef is not instantiated early enough for use
+            // here.
 #if defined(PIKA_HAVE_STDEXEC)
             using value_type =
                 typename std::decay<pika::execution::experimental::detail::single_result_t<
@@ -264,7 +264,7 @@ namespace pika::split_tuple_detail {
                 // the vector must see predecessor_done = true after
                 // taking the lock in their threads and will not add
                 // continuations to the vector.
-                std::unique_lock<mutex_type> l{mtx};
+                std::lock_guard<mutex_type> l{mtx};
             }
 
             if (!continuations.empty())
@@ -340,7 +340,8 @@ namespace pika::split_tuple_detail {
             if (!start_called.exchange(true))
             {
                 PIKA_ASSERT(os.has_value());
-                pika::execution::experimental::start(os.value());
+                // NOLINTNEXTLINE(bugprone-unchecked-optional-access)
+                pika::execution::experimental::start(*os);
             }
         }
 
