@@ -42,6 +42,7 @@ namespace pika::execution::experimental {
 # include <pika/config/constexpr.hpp>
 # include <pika/execution_base/operation_state.hpp>
 # include <pika/execution_base/receiver.hpp>
+# include <pika/functional/detail/invoke_result_plain_function.hpp>
 # include <pika/functional/detail/tag_fallback_invoke.hpp>
 # include <pika/functional/tag_invoke.hpp>
 # include <pika/type_support/equality.hpp>
@@ -202,42 +203,11 @@ namespace pika::execution::experimental {
         };
     }    // namespace detail
 
-    namespace detail {
-        template <typename S, typename R, typename Enable = void>
-        struct has_member_connect : std::false_type
-        {
-        };
-
-        template <typename S, typename R>
-        struct has_member_connect<S, R,
-            std::void_t<decltype(std::declval<S>().connect(std::declval<R>()))>> : std::true_type
-        {
-        };
-    }    // namespace detail
-
     PIKA_HOST_DEVICE_INLINE_CONSTEXPR_VARIABLE
     struct connect_t : pika::functional::detail::tag<connect_t>
     {
     } connect{};
 
-    namespace detail {
-        template <typename S, typename R, typename Enable = void>
-        struct connect_result_helper
-        {
-            struct dummy_operation_state
-            {
-            };
-            using type = dummy_operation_state;
-        };
-
-        template <typename S, typename R>
-        struct connect_result_helper<S, R,
-            std::enable_if_t<std::is_invocable<connect_t, S, R>::value>>
-          : std::invoke_result<connect_t, S, R>
-        {
-        };
-    }    // namespace detail
-
     namespace detail {
         template <typename F, typename E>
         struct as_receiver
@@ -256,19 +226,6 @@ namespace pika::execution::experimental {
         };
     }    // namespace detail
 
-    namespace detail {
-        template <typename S, typename Enable = void>
-        struct has_member_schedule : std::false_type
-        {
-        };
-
-        template <typename S>
-        struct has_member_schedule<S, std::void_t<decltype(std::declval<S>().schedule())>>
-          : std::true_type
-        {
-        };
-    }    // namespace detail
-
     PIKA_HOST_DEVICE_INLINE_CONSTEXPR_VARIABLE
     struct schedule_t : pika::functional::detail::tag<schedule_t>
     {
@@ -446,7 +403,7 @@ namespace pika::execution::experimental {
     inline constexpr bool is_scheduler_v = is_scheduler<Scheduler>::value;
 
     template <typename S, typename R>
-    using connect_result_t = std::invoke_result_t<connect_t, S, R>;
+    using connect_result_t = pika::detail::invoke_result_plain_function_t<connect_t, S, R>;
 
     struct empty_env
     {
