@@ -14,7 +14,6 @@ namespace pika::util::detail {
     [[noreturn]] void throw_bad_function_call()
     {
         pika::throw_exception(pika::error::bad_function_call,
-            "empty function object should not be used",
-            "empty_function::operator()");
+            "empty function object should not be used", "empty_function::operator()");
     }
 }    // namespace pika::util::detail
