@@ -14,12 +14,14 @@
 #include <pika/thread.hpp>
 
 #include <chrono>
+#include <cstdlib>
 
 int pika_main()
 {
     pika::apply([] { pika::this_thread::sleep_for(std::chrono::milliseconds(500)); });
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char** argv)
