@@ -18,7 +18,11 @@
 
 #include <pika/config.hpp>
 
-#include <fmt/core.h>
+#if __has_include(<fmt/base.h>)
+# include <fmt/base.h>
+#else
+# include <fmt/core.h>
+#endif
 #include <fmt/ostream.h>
 #include <fmt/printf.h>
 
