@@ -9,6 +9,8 @@
 #include <pika/init.hpp>
 #include <pika/testing.hpp>
 
+#include <cstdlib>
+
 bool invoked_main = false;
 
 int my_pika_main(int argc, char**)
@@ -17,7 +19,8 @@ int my_pika_main(int argc, char**)
     PIKA_TEST_EQ(argc, 1);
 
     invoked_main = true;
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char** argv)
