@@ -8,6 +8,7 @@
 #include <pika/testing.hpp>
 
 #include <atomic>
+#include <cstdlib>
 #include <string>
 #include <vector>
 
@@ -16,13 +17,16 @@ std::atomic<bool> main_executed(false);
 int pika_main()
 {
     main_executed = true;
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char** argv)
 {
+    std::vector<std::string> cfg = {"--pika:help"};
+
     pika::init_params init_args;
-    init_args.cfg = {"--pika:help"};
+    init_args.cfg = cfg;
 
     PIKA_TEST_EQ(pika::init(pika_main, argc, argv, init_args), 0);
 
