@@ -10,9 +10,10 @@
 #include <pika/modules/resource_partitioner.hpp>
 #include <pika/testing.hpp>
 #include <pika/thread.hpp>
-#include <pika/thread_pool_util/thread_pool_suspension_helpers.hpp>
+#include <pika/threading_base/thread_pool_base.hpp>
 
 #include <cstddef>
+#include <cstdlib>
 #include <stdexcept>
 #include <string>
 #include <utility>
@@ -28,7 +29,7 @@ int pika_main()
         pika::threads::detail::thread_pool_base& tp = pika::resource::get_thread_pool("default");
 
         // Use .get() to throw exception
-        pika::threads::detail::suspend_processing_unit(tp, 0).get();
+        tp.suspend_processing_unit_direct(0);
         PIKA_TEST_MSG(false, "Suspending should not be allowed with elasticity disabled");
     }
     catch (pika::exception const&)
@@ -38,7 +39,8 @@ int pika_main()
 
     PIKA_TEST(exception_thrown);
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
