@@ -15,8 +15,6 @@
 #include <pika/modules/runtime_configuration.hpp>
 #include <pika/runtime/config_entry.hpp>
 #include <pika/runtime/detail/runtime_fwd.hpp>
-#include <pika/runtime/get_locality_id.hpp>
-#include <pika/runtime/get_num_all_localities.hpp>
 #include <pika/runtime/get_os_thread_count.hpp>
 #include <pika/runtime/get_thread_name.hpp>
 #include <pika/runtime/get_worker_thread_num.hpp>
