@@ -1219,7 +1219,7 @@ struct fmt::formatter<pika::threads::detail::local_priority_queue_scheduler<Mute
     StagedQueuing, TerminatedQueuing>> : fmt::formatter<pika::threads::detail::scheduler_base>
 {
     template <typename FormatContext>
-    auto format(pika::threads::detail::scheduler_base const& scheduler, FormatContext& ctx)
+    auto format(pika::threads::detail::scheduler_base const& scheduler, FormatContext& ctx) const
     {
         return fmt::formatter<pika::threads::detail::scheduler_base>::format(scheduler, ctx);
     }
