@@ -863,7 +863,7 @@ struct fmt::formatter<pika::threads::detail::local_queue_scheduler<Mutex, Pendin
     StagedQueuing, TerminatedQueuing>> : fmt::formatter<pika::threads::detail::scheduler_base>
 {
     template <typename FormatContext>
-    auto format(pika::threads::detail::scheduler_base const& scheduler, FormatContext& ctx)
+    auto format(pika::threads::detail::scheduler_base const& scheduler, FormatContext& ctx) const
     {
         return fmt::formatter<pika::threads::detail::scheduler_base>::format(scheduler, ctx);
     }
