@@ -16,8 +16,7 @@
 
 namespace pika::detail::external_timer {
     inline std::shared_ptr<task_wrapper> new_task(
-        pika::detail::thread_description const&, std::uint32_t,
-        threads::detail::thread_id_type)
+        pika::detail::thread_description const&, std::uint32_t, threads::detail::thread_id_type)
     {
         return nullptr;
     }
